==> bundle-0.0.3.tgz: package/Readme.md <==

# bundle

  `bundle` generates html files from views and gzips the result, creating a
  bundle.

## Usage

    var bundle = require('bundle');

    // define a bundle

    var teacher = bundle.createBundle({
      views: 'views/bundles/teacher/'
    });

    teacher.file('index', function (params, render) {
      Teacher.findById(params.id, function (err) {
        if (err) return render(err);

        render('index.jade', {
          
        });
      });
    });

    teacher.file('misc/students', function (params, render) {
      // will create a folder 
    });

    // generate a bundle
    app.get('/generate-bundle-example/:id', function (req) {
      teacher.generate(req.param('id'), function (zip) {
          knox.upload(zip, function (err, url) {
            res.send('Download your bundle here: ' + url);
          });
      });
    });

## API

### `createBundle`

#### Options

- views: directory where template files are located
- gzip: gzip command (defaults to 'zip')
- 'view engine': defaults to 'jade'
- 'output extension': defaults to 'html'


### Authors
  - Guillermo Rauch - guillermo@learnboost.com - [Guille](http://github.com/guille)
  - Damian Suarez - damian@learnboost.com - [RetroFOX](http://github.com/retrofox)

## License 

(The MIT License)

Copyright(c) 2011 LearnBoost <dev@learnboost.com>

Permission is hereby granted, free of charge, to any person obtaining
a copy of this software and associated documentation files (the
'Software'), to deal in the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions:

The above copyright notice and this permission notice shall be
included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED 'AS IS', WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

==> bundle-0.0.5.tgz: package/Readme.md <==

# bundle

  `bundle` generates html files from views and gzips the result, creating a
  bundle.

## Usage

    var bundle = require('bundle');

    // define a bundle

    var teacher = bundle.createBundle({
      views: 'views/bundles/teacher/'
    });

    // add file
    teacher.addFile('index', function (params, render) {
      Teacher.findById(params.id, function (err) {
        if (err) return render(err);

        render('index.jade', {
          
        });
      });
    });

    // other into custom folder
    teacher.addFile('misc/students', function (params, render) {
      // will create a students.html file into a misc/ folder
    });

    // add file passing html for parameter
    teacher.addFile('list', '<ul><li>apple</li><li>orange</li><li>banana</li></ul>');

    // generate a bundle
    app.get('/generate-bundle-example/:id', function (req) {
      teacher.generate(req.param('id'), function (zip) {
          knox.upload(zip, function (err, url) {
            res.send('Download your bundle here: ' + url);
          });
      });
    });

## API

### `createBundle`

### `features`

- supports layout and partials


#### Options

- views: directory where template files are located
- gzip: gzip command (defaults to 'zip')
- 'view engine': defaults to 'jade'
- extension: defaults to 'html'


### Authors
  - Guillermo Rauch - guillermo@learnboost.com - [guille](http://github.com/guille)
  - Damian Suarez - damian@learnboost.com - [retrofox](http://github.com/retrofox)

## License 

(The MIT License)

Copyright(c) 2011 LearnBoost <dev@learnboost.com>

Permission is hereby granted, free of charge, to any person obtaining
a copy of this software and associated documentation files (the
'Software'), to deal in the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions:

The above copyright notice and this permission notice shall be
included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED 'AS IS', WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
